@@ -114,7 +114,7 @@ ImageInputFormat = Literal["yuv", "rgb", "rgba", "gray"]
 ImageOutputFormat = Literal["rgb", "rgba", "gray"]
 CameraExtension = Literal["hub", "prebuffer", "motionDetection", "objectDetection", "audioDetection", "ptz"]
 CameraFrameWorkerDecoder = Literal["pillow", "wasm"]
-CameraFrameWorkerResolution = Literal[640, 480, 320]
+CameraFrameWorkerResolution = Literal["640", "480", "320", "native"]
 AudioCodec = Literal["PCMU", "PCMA", "MPEG4-GENERIC", "opus", "G722", "MPA", "PCM", "FLAC"]
 AudioFFmpegCodec = Literal[
     "pcm_mulaw", "pcm_alaw", "aac", "libopus", "g722", "mp3", "pcm_s16be", "pcm_s16le", "flac"
@@ -922,7 +922,7 @@ class DeviceManager(Protocol):
 class FfmpegArgs(TypedDict):
     hwaccel: str
     hwaccelArgs: list[str]
-    hwaccelFilter: str
+    hwaccelFilters: list[str]
     threads: str
 
 
